==> Neon-20.1.7-sources.jar: com/gaadi/neon/util/CustomParameters.java <==
package com.gaadi.neon.util;

/**
 * @author princebatra
 * @version 1.0
 * @since 17/7/17
 */
public class CustomParameters {

    private boolean hideCameraButtonInNeutral = false;
    private boolean hideGalleryButtonInNeutral = false;
    private boolean locationRestrictive = true;
    private int setCompressBy;
    private boolean folderRestrictive;
    private String camScannerAPIKey;

    private CustomParameters(CustomParametersBuilder builder) {
        this.hideCameraButtonInNeutral = builder.hideCameraButtonInNeutral;
        this.hideGalleryButtonInNeutral = builder.hideGalleryButtonInNeutral;
        this.locationRestrictive = builder.locationRestrictive;
        this.setCompressBy = builder.setCompressBy;
        this.folderRestrictive = builder.folderRestrictive;
        this.camScannerAPIKey = builder.camScannerAPIKey;
    }

    public boolean gethideCameraButtonInNeutral() {
        return hideCameraButtonInNeutral;
    }

    public boolean getHideGalleryButtonInNeutral() {
        return hideGalleryButtonInNeutral;
    }

    public boolean getLocationRestrictive() {
        return locationRestrictive;
    }

    public int getCompressBy() {
        return setCompressBy;
    }

    public boolean getFolderRestrictive() {
        return folderRestrictive;
    }

    public String getCamScannerAPIKey(){
        return camScannerAPIKey;
    }


    public static class CustomParametersBuilder {

        private boolean hideCameraButtonInNeutral;
        private boolean hideGalleryButtonInNeutral;
        private boolean locationRestrictive = true;
        private int setCompressBy;
        private boolean folderRestrictive;
        private String camScannerAPIKey = "";


        public CustomParametersBuilder sethideCameraButtonInNeutral(boolean hide) {
            this.hideCameraButtonInNeutral = hide;
            return this;
        }

        public CustomParametersBuilder setHideGalleryButtonInNeutral(boolean hide) {
            this.hideGalleryButtonInNeutral = hide;
            return this;
        }

        public CustomParametersBuilder setLocationRestrictive(boolean locationRestrictive) {
            this.locationRestrictive = locationRestrictive;
            return this;
        }

        public CustomParametersBuilder setCompressBy(int setCompressBy) {
            this.setCompressBy = setCompressBy;
            return this;
        }

        public CustomParametersBuilder setFolderRestrictive(boolean folderRestrictive) {
            this.folderRestrictive = folderRestrictive;
            return this;
        }

        public CustomParametersBuilder setCamScannerAPIKey(String camScannerAPIKey){
            this.camScannerAPIKey = camScannerAPIKey;
            return this;
        }

        public CustomParameters build() {
            CustomParameters user = new CustomParameters(this);
            return user;
        }

    }
}

==> Neon-20.1.8-sources.jar: com/gaadi/neon/util/CustomParameters.java <==
package com.gaadi.neon.util;

/**
 * @author princebatra
 * @version 1.0
 * @since 17/7/17
 */
public class CustomParameters {

    private boolean hideCameraButtonInNeutral = false;
    private boolean hideGalleryButtonInNeutral = false;
    private boolean locationRestrictive = true;
    private int setCompressBy;
    private boolean folderRestrictive;
    private String folderName;

    private CustomParameters(CustomParametersBuilder builder) {
        this.hideCameraButtonInNeutral = builder.hideCameraButtonInNeutral;
        this.hideGalleryButtonInNeutral = builder.hideGalleryButtonInNeutral;
        this.locationRestrictive = builder.locationRestrictive;
        this.setCompressBy = builder.setCompressBy;
        this.folderRestrictive = builder.folderRestrictive;
        this.folderName = builder.folderName;
    }

    public boolean gethideCameraButtonInNeutral() {
        return hideCameraButtonInNeutral;
    }

    public boolean getHideGalleryButtonInNeutral() {
        return hideGalleryButtonInNeutral;
    }

    public boolean getLocationRestrictive() {
        return locationRestrictive;
    }

    public int getCompressBy() {
        return setCompressBy;
    }

    public boolean getFolderRestrictive() {
        return folderRestrictive;
    }

    public String getFolderName() {
        return folderName;
    }


    public static class CustomParametersBuilder {

        private boolean hideCameraButtonInNeutral;
        private boolean hideGalleryButtonInNeutral;
        private boolean locationRestrictive = true;
        private int setCompressBy;
        private boolean folderRestrictive;
        private String folderName;


        public CustomParametersBuilder sethideCameraButtonInNeutral(boolean hide) {
            this.hideCameraButtonInNeutral = hide;
            return this;
        }

        public CustomParametersBuilder setHideGalleryButtonInNeutral(boolean hide) {
            this.hideGalleryButtonInNeutral = hide;
            return this;
        }

        public CustomParametersBuilder setLocationRestrictive(boolean locationRestrictive) {
            this.locationRestrictive = locationRestrictive;
            return this;
        }

        public CustomParametersBuilder setCompressBy(int setCompressBy) {
            this.setCompressBy = setCompressBy;
            return this;
        }

        public CustomParametersBuilder setFolderRestrictive(boolean folderRestrictive) {
            this.folderRestrictive = folderRestrictive;
            return this;
        }

        public CustomParametersBuilder setFolderName(String folderName) {
            this.folderName = folderName;
            return this;
        }

        public CustomParameters build() {
            CustomParameters user = new CustomParameters(this);
            return user;
        }

    }
}
